==> kubernetes-model-core-5.2.1-sources.jar: io/fabric8/kubernetes/api/model/AzureFilePersistentVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class AzureFilePersistentVolumeSourceFluentImpl<A extends AzureFilePersistentVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements AzureFilePersistentVolumeSourceFluent<A> {

    private Boolean readOnly;
    private String secretName;
    private String secretNamespace;
    private String shareName;

    public AzureFilePersistentVolumeSourceFluentImpl() {
    }

    public AzureFilePersistentVolumeSourceFluentImpl(AzureFilePersistentVolumeSource instance) {
        this.withReadOnly(instance.getReadOnly()); 
        this.withSecretName(instance.getSecretName()); 
        this.withSecretNamespace(instance.getSecretNamespace()); 
        this.withShareName(instance.getShareName()); 
    }

    public Boolean isReadOnly() {
        return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly) {
        this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly() {
        return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public String getSecretName() {
        return this.secretName;
    }

    public A withSecretName(String secretName) {
        this.secretName=secretName; return (A) this;
    }

    public Boolean hasSecretName() {
        return this.secretName != null;
    }

    public A withNewSecretName(String arg1) {
        return (A)withSecretName(new String(arg1));
    }

    public A withNewSecretName(StringBuilder arg1) {
        return (A)withSecretName(new String(arg1));
    }

    public A withNewSecretName(StringBuffer arg1) {
        return (A)withSecretName(new String(arg1));
    }

    public String getSecretNamespace() {
        return this.secretNamespace;
    }

    public A withSecretNamespace(String secretNamespace) {
        this.secretNamespace=secretNamespace; return (A) this;
    }

    public Boolean hasSecretNamespace() {
        return this.secretNamespace != null;
    }

    public A withNewSecretNamespace(String arg1) {
        return (A)withSecretNamespace(new String(arg1));
    }

    public A withNewSecretNamespace(StringBuilder arg1) {
        return (A)withSecretNamespace(new String(arg1));
    }

    public A withNewSecretNamespace(StringBuffer arg1) {
        return (A)withSecretNamespace(new String(arg1));
    }

    public String getShareName() {
        return this.shareName;
    }

    public A withShareName(String shareName) {
        this.shareName=shareName; return (A) this;
    }

    public Boolean hasShareName() {
        return this.shareName != null;
    }

    public A withNewShareName(String arg1) {
        return (A)withShareName(new String(arg1));
    }

    public A withNewShareName(StringBuilder arg1) {
        return (A)withShareName(new String(arg1));
    }

    public A withNewShareName(StringBuffer arg1) {
        return (A)withShareName(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AzureFilePersistentVolumeSourceFluentImpl that = (AzureFilePersistentVolumeSourceFluentImpl) o;
        if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
        if (secretName != null ? !secretName.equals(that.secretName) :that.secretName != null) return false;
        if (secretNamespace != null ? !secretNamespace.equals(that.secretNamespace) :that.secretNamespace != null) return false;
        if (shareName != null ? !shareName.equals(that.shareName) :that.shareName != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(readOnly,  secretName,  secretNamespace,  shareName,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/AzureFilePersistentVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class AzureFilePersistentVolumeSourceFluentImpl<A extends AzureFilePersistentVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements AzureFilePersistentVolumeSourceFluent<A> {

    private Boolean readOnly;
    private String secretName;
    private String secretNamespace;
    private String shareName;

    public AzureFilePersistentVolumeSourceFluentImpl() {
    }

    public AzureFilePersistentVolumeSourceFluentImpl(AzureFilePersistentVolumeSource instance) {
        this.withReadOnly(instance.getReadOnly()); 
        this.withSecretName(instance.getSecretName()); 
        this.withSecretNamespace(instance.getSecretNamespace()); 
        this.withShareName(instance.getShareName()); 
    }

    public Boolean getReadOnly() {
        return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly) {
        this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly() {
        return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public String getSecretName() {
        return this.secretName;
    }

    public A withSecretName(String secretName) {
        this.secretName=secretName; return (A) this;
    }

    public Boolean hasSecretName() {
        return this.secretName != null;
    }

    public A withNewSecretName(StringBuilder arg1) {
        return (A)withSecretName(new String(arg1));
    }

    public A withNewSecretName(int[] arg1,int arg2,int arg3) {
        return (A)withSecretName(new String(arg1, arg2, arg3));
    }

    public A withNewSecretName(char[] arg1) {
        return (A)withSecretName(new String(arg1));
    }

    public A withNewSecretName(StringBuffer arg1) {
        return (A)withSecretName(new String(arg1));
    }

    public A withNewSecretName(byte[] arg1,int arg2) {
        return (A)withSecretName(new String(arg1, arg2));
    }

    public A withNewSecretName(byte[] arg1) {
        return (A)withSecretName(new String(arg1));
    }

    public A withNewSecretName(char[] arg1,int arg2,int arg3) {
        return (A)withSecretName(new String(arg1, arg2, arg3));
    }

    public A withNewSecretName(byte[] arg1,int arg2,int arg3) {
        return (A)withSecretName(new String(arg1, arg2, arg3));
    }

    public A withNewSecretName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withSecretName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewSecretName(String arg1) {
        return (A)withSecretName(new String(arg1));
    }

    public String getSecretNamespace() {
        return this.secretNamespace;
    }

    public A withSecretNamespace(String secretNamespace) {
        this.secretNamespace=secretNamespace; return (A) this;
    }

    public Boolean hasSecretNamespace() {
        return this.secretNamespace != null;
    }

    public A withNewSecretNamespace(StringBuilder arg1) {
        return (A)withSecretNamespace(new String(arg1));
    }

    public A withNewSecretNamespace(int[] arg1,int arg2,int arg3) {
        return (A)withSecretNamespace(new String(arg1, arg2, arg3));
    }

    public A withNewSecretNamespace(char[] arg1) {
        return (A)withSecretNamespace(new String(arg1));
    }

    public A withNewSecretNamespace(StringBuffer arg1) {
        return (A)withSecretNamespace(new String(arg1));
    }

    public A withNewSecretNamespace(byte[] arg1,int arg2) {
        return (A)withSecretNamespace(new String(arg1, arg2));
    }

    public A withNewSecretNamespace(byte[] arg1) {
        return (A)withSecretNamespace(new String(arg1));
    }

    public A withNewSecretNamespace(char[] arg1,int arg2,int arg3) {
        return (A)withSecretNamespace(new String(arg1, arg2, arg3));
    }

    public A withNewSecretNamespace(byte[] arg1,int arg2,int arg3) {
        return (A)withSecretNamespace(new String(arg1, arg2, arg3));
    }

    public A withNewSecretNamespace(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withSecretNamespace(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewSecretNamespace(String arg1) {
        return (A)withSecretNamespace(new String(arg1));
    }

    public String getShareName() {
        return this.shareName;
    }

    public A withShareName(String shareName) {
        this.shareName=shareName; return (A) this;
    }

    public Boolean hasShareName() {
        return this.shareName != null;
    }

    public A withNewShareName(StringBuilder arg1) {
        return (A)withShareName(new String(arg1));
    }

    public A withNewShareName(int[] arg1,int arg2,int arg3) {
        return (A)withShareName(new String(arg1, arg2, arg3));
    }

    public A withNewShareName(char[] arg1) {
        return (A)withShareName(new String(arg1));
    }

    public A withNewShareName(StringBuffer arg1) {
        return (A)withShareName(new String(arg1));
    }

    public A withNewShareName(byte[] arg1,int arg2) {
        return (A)withShareName(new String(arg1, arg2));
    }

    public A withNewShareName(byte[] arg1) {
        return (A)withShareName(new String(arg1));
    }

    public A withNewShareName(char[] arg1,int arg2,int arg3) {
        return (A)withShareName(new String(arg1, arg2, arg3));
    }

    public A withNewShareName(byte[] arg1,int arg2,int arg3) {
        return (A)withShareName(new String(arg1, arg2, arg3));
    }

    public A withNewShareName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withShareName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewShareName(String arg1) {
        return (A)withShareName(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AzureFilePersistentVolumeSourceFluentImpl that = (AzureFilePersistentVolumeSourceFluentImpl) o;
        if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
        if (secretName != null ? !secretName.equals(that.secretName) :that.secretName != null) return false;
        if (secretNamespace != null ? !secretNamespace.equals(that.secretNamespace) :that.secretNamespace != null) return false;
        if (shareName != null ? !shareName.equals(that.shareName) :that.shareName != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(readOnly,  secretName,  secretNamespace,  shareName,  super.hashCode());
    }

}
